@@ -6,8 +6,7 @@ from typing import Optional, TypedDict
 from PIL import ImageFont
 from typing_extensions import NotRequired
 
-from snip.api.snippets import get_font as get_font_from_deployment
-
+from ..api.snippets import get_font as get_font_from_deployment
 from ..logger import log
 from .base import BaseSnip
 
