@@ -4,6 +4,8 @@ from snip.snippets.array import ArraySnip
 from snip.snippets.image import ImageSnip
 from snip.snippets.text import TextSnip
 
+from test_text import get_font
+
 
 class TestArraySnip:
     text = TextSnip(text="Hello World", book_id=1)
@@ -29,6 +31,8 @@ class TestArraySnip:
         with pytest.raises(NotImplementedError):
             array.size
 
-    def test_boundings(self):
+    def test_boundings(self, monkeypatch):
+        monkeypatch.setattr("snip.snippets.text.get_font_from_deployment", get_font)
+
         array = ArraySnip(book_id=1, snippets=[self.text, self.image])
         assert array.bounding_box == (0, 0, 200, 1000)
